==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/is.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Uppgefið nafn er of langt",
    "The given web address is too long" : "Uppgefið veffang er of langt",
    "The given web address is not a valid URL" : "Uppgefið veffang er ekki gild vefslóð",
    "The given legal notice address is too long" : "Uppgefið veffang lagatexta er of langt",
    "The given legal notice address is not a valid URL" : "Uppgefið veffang lagatexta er ekki gild vefslóð",
    "The given privacy policy address is too long" : "Veffang á stefnu um meðferð persónulegra gagna er of langt",
    "The given privacy policy address is not a valid URL" : "Veffang á stefnu um meðferð persónulegra gagna er ekki gild vefslóð",
    "The given slogan is too long" : "Uppgefið slagorð er of langt",
    "The given color is invalid" : "Uppgefinn litur er ógildur",
    "Disable-user-theming should be true or false" : "Gera-þemu-notanda-óvirk ætti að vera satt eða ósatt",
    "Saved" : "Vistað",
    "Invalid app given" : "Ógilt forrit gefið",
    "Invalid type for setting \"defaultApp\" given" : "Ógild tegund gefin fyrir stillinguna \"defaultApp\"",
    "Invalid setting key" : "Ógildur stillingalykill",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "No file uploaded" : "Engin skrá var send inn",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Þú ert nú þegar að nota sérsniðið þema. Mögulega gæti það skrifað yfir stillingar í þemaforriti.",
    "Theming" : "Þemu",
    "Appearance and accessibility" : "Útlit og aðgengi",
    "PHP Imagick module" : "PHP Imagick eining",
    "Dark theme with high contrast mode" : "Dökkt þema með mikil birtuskil",
    "Enable dark high contrast mode" : "Virkja dökkt þema með mikil birtuskil",
    "Similar to the high contrast mode, but with dark colours." : "Svipað þemanu með mikil birtuskil, en með dökka liti.",
    "Dark theme" : "Dökkt þema",
    "Enable dark theme" : "Virkja dökkt þema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Dökkt þema til að minnka álag á augun meðal annars með því að minnka heildarljósmagn og birtustig.",
    "System default theme" : "Sjálfgefið þema í kerfinu",
    "Enable the system default" : "Virkja sjálfgefið þema kerfis",
    "Using the default system appearance." : "Nota sjálfgefið útlit kerfisins.",
    "Dyslexia font" : "Dyslexia letur",
    "Enable dyslexia font" : "Virkja letur fyrir lesblinda",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic eru frjálsar leturgerðir sem eru hannaðar til að ráða bug á eða minnka vægi ýmissa villna sem stafa af lesblindu (dyslexia).",
    "High contrast mode" : "Mikil birtuskil",
    "Enable high contrast mode" : "Virkja ham með mikil birtuskil",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Þema með mikil birtuskil til að auðvelda vafur. Sjónræn gæði minnka en skýrleiki eykst",
    "Light theme" : "Ljóst þema",
    "Enable the default light theme" : "Virkja sjálfgefið ljóst þema",
    "The default light appearance." : "Sjálfgefna ljósa útlitið.",
    "Legal notice" : "Lagaleg atriði",
    "Privacy policy" : "Stefna um meðferð persónulegra gagna",
    "Adjust the Nextcloud theme" : "Laga Nextcloud þema",
    "Name" : "Heiti",
    "Web link" : "Veftengill",
    "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
    "Slogan" : "Slagorð",
    "Primary color" : "Aðallitur",
    "Legal notice link" : "Tengill á lagaleg atriði",
    "Privacy policy link" : "Tengill á stefnu um meðferð persónulegra gagna",
    "Header logo" : "Táknmerki í haus",
    "Upload new header logo" : "Senda inn nýtt táknmerki fyrir síðuhaus",
    "Favicon" : "Veftákn",
    "Upload new favicon" : "Senda inn nýja táknmynd",
    "User settings" : "Notandastillingar",
    "Disable user theming" : "Gera þemu notanda óvirk",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Þemu gera þér kleift að breyta útliti og hegðun þíns eintaks af viðmótinu auk studdra biðlaraforrita. Það verður sýnilegt öllum notendum.",
    "Background color" : "Bakgrunnslitur",
    "Upload new logo" : "Senda inn nýtt táknmerki",
    "Logo" : "Táknmerki",
    "Upload new background and login image" : "Senda inn nýjan bakgrunn og innskráningarmynd",
    "Background and login image" : "Bakgrunnur og innskráningarmynd",
    "Advanced options" : "Ítarlegir valkostir",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Settu inn ImageMagick PHP forritsviðaukann með stuðningi við SVG-myndir til að útbúa sjálfvirkt veftáknmyndir byggðar á innsendu táknmerki og lit.",
    "Appearance and accessibility settings" : "Stillingar útlits og aðgengis",
    "Misc accessibility options" : "Ýmsir valkostir fyrir auðveldað aðgengi",
    "Customization has been disabled by your administrator" : "Sérsníðing hefur verið gerð óvirk af kerfisstjóra",
    "Background and color" : "Bakgrunnur og litir",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "Disable all keyboard shortcuts" : "Gera alla flýtilykla óvirka",
    "Current selected app: {app}, position {position} of {total}" : "Valið forrit: {app}, staða {position} af {total}",
    "Move up" : "Færa upp",
    "Move down" : "Færa niður",
    "Select a background from your files" : "Veldu bakgrunn úr skránum þínum",
    "Select background" : "Veldu bakgrunn",
    "No background has been selected" : "Enginn bakgrunnur hefur verið valinn",
    "Custom background" : "Sérsniðinn bakgrunnur",
    "Plain background" : "Einfaldur bakgrunnur",
    "Default background" : "Sjálfgefinn bakgrunnur",
    "Theme selection is enforced" : "Val á þema er þvingað",
    "Could not set the app order" : "Gat ekki stillt röð forrita",
    "Could not reset the app order" : "Gat ekki endurstillt röð forrita",
    "Navigation bar settings" : "Stillingar flakkstiku",
    "The default app can not be changed because it was configured by the administrator." : "Ekki er hægt að breyta sjálfgefnu forriti því það var stillt af kerfisstjóra.",
    "The app order was changed, to see it in action you have to reload the page." : "Röð forrita var breytt, til að sjá það í verki ættirðu að hlaða síðunni aftur inn.",
    "Reset default app order" : "Endurstilla sjálfgefna röð forrita",
    "Could not set primary color" : "Ekki tókst að setja aðallit",
    "Reset primary color" : "Endursetja aðallit",
    "Could not set global default apps" : "Gat ekki sett víðvær sjálfgefin forrit",
    "Default app" : "Sjálfgefið forrit",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Sjálfgefna forritið er það forrit sem t.d. opnast eftir innskráningu eða þegar smellt er á táknmerkið í valmyndinni.",
    "Use custom default app" : "Nota sérsniðið sjálfgefið forrit",
    "Global default app" : "Víðvært sjálfgefið forrit",
    "Global default apps" : "Víðvær sjálfgefin forrit",
    "Default app priority" : "Sjálfgefinn forgangur forrits",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Ef forrit er ekki virkjað fyrir notanda, verður næsta forrit með lægri forgangi notað.",
    "Select a custom color" : "Veldu sérsniðinn lit",
    "Reset to default" : "Endurstilla á sjálfgefið",
    "Upload" : "Senda inn",
    "Remove background image" : "Fjarlægja bakgrunnsmynd",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Aðgengi fyrir alla er okkur mikilvægt. Við fylgjum vefstöðlum oggöngum úr skugga um að allt sé nothæft án þess að nota tölvumús, auk þess að hjálpartæki á borð við skjálesara virki. Við miðum að samhæfni við {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 á stigi AA, og höfum meira að segja háskerpuþemað miðað við stig AAA."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/is.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Uppgefið nafn er of langt",
    "The given web address is too long" : "Uppgefið veffang er of langt",
    "The given web address is not a valid URL" : "Uppgefið veffang er ekki gild vefslóð",
    "The given legal notice address is too long" : "Uppgefið veffang lagatexta er of langt",
    "The given legal notice address is not a valid URL" : "Uppgefið veffang lagatexta er ekki gild vefslóð",
    "The given privacy policy address is too long" : "Veffang á stefnu um meðferð persónulegra gagna er of langt",
    "The given privacy policy address is not a valid URL" : "Veffang á stefnu um meðferð persónulegra gagna er ekki gild vefslóð",
    "The given slogan is too long" : "Uppgefið slagorð er of langt",
    "The given color is invalid" : "Uppgefinn litur er ógildur",
    "Invalid setting key" : "Ógildur stillingalykill",
    "Saved" : "Vistað",
    "Invalid app given" : "Ógilt forrit gefið",
    "Invalid type for setting \"defaultApp\" given" : "Ógild tegund gefin fyrir stillinguna \"defaultApp\"",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "No file uploaded" : "Engin skrá var send inn",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Þú ert nú þegar að nota sérsniðið þema. Mögulega gæti það skrifað yfir stillingar í þemaforriti.",
    "Theming" : "Þemu",
    "Appearance and accessibility" : "Útlit og aðgengi",
    "PHP Imagick module" : "PHP Imagick eining",
    "Dark theme with high contrast mode" : "Dökkt þema með mikil birtuskil",
    "Enable dark high contrast mode" : "Virkja dökkt þema með mikil birtuskil",
    "Similar to the high contrast mode, but with dark colours." : "Svipað þemanu með mikil birtuskil, en með dökka liti.",
    "Dark theme" : "Dökkt þema",
    "Enable dark theme" : "Virkja dökkt þema",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Dökkt þema til að minnka álag á augun meðal annars með því að minnka heildarljósmagn og birtustig.",
    "System default theme" : "Sjálfgefið þema í kerfinu",
    "Enable the system default" : "Virkja sjálfgefið þema kerfis",
    "Using the default system appearance." : "Nota sjálfgefið útlit kerfisins.",
    "Dyslexia font" : "Dyslexia letur",
    "Enable dyslexia font" : "Virkja letur fyrir lesblinda",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic eru frjálsar leturgerðir sem eru hannaðar til að ráða bug á eða minnka vægi ýmissa villna sem stafa af lesblindu (dyslexia).",
    "High contrast mode" : "Mikil birtuskil",
    "Enable high contrast mode" : "Virkja ham með mikil birtuskil",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Þema með mikil birtuskil til að auðvelda vafur. Sjónræn gæði minnka en skýrleiki eykst",
    "Light theme" : "Ljóst þema",
    "Enable the default light theme" : "Virkja sjálfgefið ljóst þema",
    "The default light appearance." : "Sjálfgefna ljósa útlitið.",
    "Legal notice" : "Lagaleg atriði",
    "Privacy policy" : "Stefna um meðferð persónulegra gagna",
    "Adjust the Nextcloud theme" : "Laga Nextcloud þema",
    "Could not set global default apps" : "Gat ekki sett víðvær sjálfgefin forrit",
    "Navigation bar settings" : "Stillingar flakkstiku",
    "Default app" : "Sjálfgefið forrit",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Sjálfgefna forritið er það forrit sem t.d. opnast eftir innskráningu eða þegar smellt er á táknmerkið í valmyndinni.",
    "Use custom default app" : "Nota sérsniðið sjálfgefið forrit",
    "Global default app" : "Víðvært sjálfgefið forrit",
    "Global default apps" : "Víðvær sjálfgefin forrit",
    "Default app priority" : "Sjálfgefinn forgangur forrits",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Ef forrit er ekki virkjað fyrir notanda, verður næsta forrit með lægri forgangi notað.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Þemu gera þér kleift að breyta útliti og hegðun þíns eintaks af viðmótinu auk studdra biðlaraforrita. Það verður sýnilegt öllum notendum.",
    "Name" : "Heiti",
    "Web link" : "Veftengill",
    "Slogan" : "Slagorð",
    "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
    "Legal notice link" : "Tengill á lagaleg atriði",
    "Privacy policy link" : "Tengill á stefnu um meðferð persónulegra gagna",
    "Background and color" : "Bakgrunnur og litir",
    "Primary color" : "Aðallitur",
    "Background color" : "Bakgrunnslitur",
    "Remove background image" : "Fjarlægja bakgrunnsmynd",
    "Favicon" : "Veftákn",
    "Logo" : "Táknmerki",
    "Disable user theming" : "Gera þemu notanda óvirk",
    "Current selected app: {app}, position {position} of {total}" : "Valið forrit: {app}, staða {position} af {total}",
    "Move up" : "Færa upp",
    "Move down" : "Færa niður",
    "Theme selection is enforced" : "Val á þema er þvingað",
    "Could not set the app order" : "Gat ekki stillt röð forrita",
    "Could not reset the app order" : "Gat ekki endurstillt röð forrita",
    "The default app can not be changed because it was configured by the administrator." : "Ekki er hægt að breyta sjálfgefnu forriti því það var stillt af kerfisstjóra.",
    "The app order was changed, to see it in action you have to reload the page." : "Röð forrita var breytt, til að sjá það í verki ættirðu að hlaða síðunni aftur inn.",
    "Reset default app order" : "Endurstilla sjálfgefna röð forrita",
    "Select a background from your files" : "Veldu bakgrunn úr skránum þínum",
    "Select background" : "Veldu bakgrunn",
    "Custom background" : "Sérsniðinn bakgrunnur",
    "Plain background" : "Einfaldur bakgrunnur",
    "Default background" : "Sjálfgefinn bakgrunnur",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "Disable all keyboard shortcuts" : "Gera alla flýtilykla óvirka",
    "Could not set primary color" : "Ekki tókst að setja aðallit",
    "Reset primary color" : "Endursetja aðallit",
    "Reset to default" : "Endurstilla á sjálfgefið",
    "Appearance and accessibility settings" : "Stillingar útlits og aðgengis",
    "Misc accessibility options" : "Ýmsir valkostir fyrir auðveldað aðgengi",
    "Customization has been disabled by your administrator" : "Sérsníðing hefur verið gerð óvirk af kerfisstjóra",
    "Disable-user-theming should be true or false" : "Gera-þemu-notanda-óvirk ætti að vera satt eða ósatt",
    "Header logo" : "Táknmerki í haus",
    "Upload new header logo" : "Senda inn nýtt táknmerki fyrir síðuhaus",
    "Upload new favicon" : "Senda inn nýja táknmynd",
    "User settings" : "Notandastillingar",
    "Upload new logo" : "Senda inn nýtt táknmerki",
    "Upload new background and login image" : "Senda inn nýjan bakgrunn og innskráningarmynd",
    "Background and login image" : "Bakgrunnur og innskráningarmynd",
    "Advanced options" : "Ítarlegir valkostir",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Settu inn ImageMagick PHP forritsviðaukann með stuðningi við SVG-myndir til að útbúa sjálfvirkt veftáknmyndir byggðar á innsendu táknmerki og lit.",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Aðgengi fyrir alla er okkur mikilvægt. Við fylgjum vefstöðlum oggöngum úr skugga um að allt sé nothæft án þess að nota tölvumús, auk þess að hjálpartæki á borð við skjálesara virki. Við miðum að samhæfni við {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 á stigi AA, og höfum meira að segja háskerpuþemað miðað við stig AAA.",
    "No background has been selected" : "Enginn bakgrunnur hefur verið valinn",
    "Select a custom color" : "Veldu sérsniðinn lit",
    "Upload" : "Senda inn"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
